module Security
  class RejectAllRequestsLocal < RuboCop::Cop::Cop
    RAILS_ENV = ['integration', 'staging', 'production']

    MSG = "RAILS CONFIG: Restrict usage of option 'consider_all_requests_local' on #{RAILS_ENV.join(', ')} envs"
    def_node_matcher "consider_all_requests_local", '(send (send nil :config) :consider_all_requests_local= (true))'

    def on_send(node)
      source = node.source
      file_name = node.loc.operator.to_s

      add_offense(node, location: :selector) if found_match(source) && black_listed?(file_name)
    end

    def black_listed?(string)
      RAILS_ENV.each_with_object([]) do |env, results|
        results << string.include?(env)
      end.any?(true)
    end

    def found_match(string)
      string.match(/config.consider_all_requests\S?.*=\s?.*true/) ? true : false
    end
  end
end
